export * from './abi'
export * from './utils'

// Viem Hex like type
type Hex = `0x${string}`

/**
 * The eco protocol chain configuration type. Represents
 * all the deployed contracts on a chain.
 * 
 * @packageDocumentation
 * @module index
 */
export type EcoChainConfig = {
  Prover?: Hex
  IntentSource: Hex
  Inbox: Hex
  HyperProver: Hex
}

/**
 * The chain ids for the eco protocol
 * 
 * @packageDocumentation
 * @module index
 */
export type EcoChainIds = "10" | "137" | "8453" | "42161" | "42161-pre" | "8453-pre" | "10-pre" | "137-pre"

/**
 * This file contains the addresses of the contracts deployed on the EcoProtocol network
 * for the current npm package release. The addresses are generated by the deploy script.
 * 
 * @packageDocumentation
 * @module index
*/
export const EcoProtocolAddresses: Record<EcoChainIds, EcoChainConfig> = 
  {
    "10": {
      "IntentSource": "0xFb26179cF0bcb30bC65eF2f142a418EC66Fa973A",
      "Inbox": "0xB9D8c17e421390a0999B14eBcc3c37A6832C7CAd",
      "HyperProver": "0xE9128C6E6743F7fff506619Aadf00F52c5bFB925"
    },
    "137": {
      "IntentSource": "0xFb26179cF0bcb30bC65eF2f142a418EC66Fa973A",
      "Inbox": "0xB9D8c17e421390a0999B14eBcc3c37A6832C7CAd",
      "HyperProver": "0xE9128C6E6743F7fff506619Aadf00F52c5bFB925"
    },
    "8453": {
      "IntentSource": "0xFb26179cF0bcb30bC65eF2f142a418EC66Fa973A",
      "Inbox": "0xB9D8c17e421390a0999B14eBcc3c37A6832C7CAd",
      "HyperProver": "0xE9128C6E6743F7fff506619Aadf00F52c5bFB925"
    },
    "42161": {
      "IntentSource": "0xFb26179cF0bcb30bC65eF2f142a418EC66Fa973A",
      "Inbox": "0xB9D8c17e421390a0999B14eBcc3c37A6832C7CAd",
      "HyperProver": "0xE9128C6E6743F7fff506619Aadf00F52c5bFB925"
    },
    "42161-pre": {
      "IntentSource": "0xC9Ed3d804A604EAdddc8B1313b4293B680Ae2Fe5",
      "Inbox": "0x5334Ff242c3eF1972D5c877eee9a854CC8C46d91",
      "HyperProver": "0xE93a1E7FcB3DA4273d12e6b67e90504c31f6117A"
    },
    "8453-pre": {
      "IntentSource": "0xC9Ed3d804A604EAdddc8B1313b4293B680Ae2Fe5",
      "Inbox": "0x5334Ff242c3eF1972D5c877eee9a854CC8C46d91",
      "HyperProver": "0xE93a1E7FcB3DA4273d12e6b67e90504c31f6117A"
    },
    "10-pre": {
      "IntentSource": "0xC9Ed3d804A604EAdddc8B1313b4293B680Ae2Fe5",
      "Inbox": "0x5334Ff242c3eF1972D5c877eee9a854CC8C46d91",
      "HyperProver": "0xE93a1E7FcB3DA4273d12e6b67e90504c31f6117A"
    },
    "137-pre": {
      "IntentSource": "0xC9Ed3d804A604EAdddc8B1313b4293B680Ae2Fe5",
      "Inbox": "0x5334Ff242c3eF1972D5c877eee9a854CC8C46d91",
      "HyperProver": "0xE93a1E7FcB3DA4273d12e6b67e90504c31f6117A"
    }
  } as const
